Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(417)

Unified Diff: remoting/host/desktop_environment.h

Issue 10696134: remoting/host: Rename Capturer to VideoFrameCapturer. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/host/desktop_environment.h
diff --git a/remoting/host/desktop_environment.h b/remoting/host/desktop_environment.h
index 745cf2f6dccd2c69dce16c9d8e1e1d5502a50de3..70964c338400d4786a77dc9960ada6f70eedf149 100644
--- a/remoting/host/desktop_environment.h
+++ b/remoting/host/desktop_environment.h
@@ -13,13 +13,13 @@
namespace remoting {
-class Capturer;
class ChromotingHostContext;
+class VideoFrameCapturer;
namespace protocol {
class ClipboardStub;
class HostEventStub;
-};
+}
class DesktopEnvironment {
public:
@@ -33,27 +33,27 @@ class DesktopEnvironment {
static scoped_ptr<DesktopEnvironment> CreateFake(
ChromotingHostContext* context,
- scoped_ptr<Capturer> capturer,
+ scoped_ptr<VideoFrameCapturer> capturer,
scoped_ptr<EventExecutor> event_executor);
virtual ~DesktopEnvironment();
- Capturer* capturer() const { return capturer_.get(); }
+ VideoFrameCapturer* capturer() const { return capturer_.get(); }
EventExecutor* event_executor() const { return event_executor_.get(); }
void OnSessionStarted(scoped_ptr<protocol::ClipboardStub> client_clipboard);
void OnSessionFinished();
private:
DesktopEnvironment(ChromotingHostContext* context,
- scoped_ptr<Capturer> capturer,
+ scoped_ptr<VideoFrameCapturer> capturer,
scoped_ptr<EventExecutor> event_executor);
// Host context used to make sure operations are run on the correct thread.
// This is owned by the ChromotingHost.
ChromotingHostContext* context_;
- // Capturer to be used by ScreenRecorder.
- scoped_ptr<Capturer> capturer_;
+ // VideoFrameCapturer to be used by ScreenRecorder.
+ scoped_ptr<VideoFrameCapturer> capturer_;
// Executes input and clipboard events received from the client.
scoped_ptr<EventExecutor> event_executor_;

Powered by Google App Engine
This is Rietveld 408576698